@@ -7,23 +7,21 @@ Authors
   - Yevgeniy Yakusevich <eugenethree@gmail.com>
 """
 
-
-from PIL import Image
 import numpy as np
 
 from xicsrt.tools.xicsrt_doc import dochelper
 from xicsrt.optics._XicsrtOpticMesh import XicsrtOpticMesh
 
+
 @dochelper
 class XicsrtOpticDetector(XicsrtOpticMesh):
     """
     A class for detectors.
 
-    Programming Notes
-    -----------------
+    **Programming Notes**
+
     For now the detector class is exactly the same as the generic optic.
-    In the future this may change based on defaults or how absorbtion is
+    In the future this may change based on defaults or how quantum efficiency is
     handled.
     """
     pass
-        
