@@ -6,7 +6,7 @@
     James Kring <jdk0026@tigermail.auburn.edu>
 
 Entry point to XICSRT.
-Contains the main function that are called to perform raytracing.
+Contains the main functions that are called to perform raytracing.
 """
 
 import numpy as np
@@ -24,74 +24,6 @@ from xicsrt import xicsrt_input
 from xicsrt.objects._Dispatcher import Dispatcher
 from xicsrt.objects._RayArray import RayArray
 
-def raytrace_single(config, internal=False):
-    """
-    Perform a series of ray tracing iterations.
-
-    If history is enabled, sort the rays into those that are detected and 
-    those that are lost (found and lost). The found ray history will be 
-    returned in full. The lost ray history will be truncated to allow 
-    analysis of lost ray pattern while still limiting memory usage.
-    """
-    profiler.start('raytrace')
-
-    # Update the default config with the user config.
-    config = xicsrt_config.get_config(config)
-    config = xicsrt_config.config_to_numpy(config)
-    check_config(config)
-
-    logging.info('Seeding np.random with {}'.format(config['general']['random_seed']))
-    np.random.seed(config['general']['random_seed'])
-    
-    num_iter = config['general']['number_of_iter']
-    max_lost_iter = int(config['general']['history_max_lost']/num_iter)
-
-    # Setup the dispatchers.
-    if 'filters' in config:
-        filters = Dispatcher(config, 'filters')
-        filters.instantiate()
-        filters.setup()
-        filters.initialize()
-        config['filters'] = filters.get_config()
-    else:
-        filters = None
-
-    sources = Dispatcher(config, 'sources')
-    sources.instantiate()
-    sources.apply_filters(filters)
-    sources.setup()
-    sources.initialize()
-    config['sources'] = sources.get_config()
-
-    optics = Dispatcher(config, 'optics')
-    optics.instantiate()
-    optics.setup()
-    optics.initialize()
-    config['optics'] = optics.get_config()
-
-    # Do the actual raytracing
-    output_list = []
-    for ii in range(num_iter):
-        logging.info('Starting iteration: {} of {}'.format(ii + 1, num_iter))
-        
-        single = _raytrace_iter(config, sources, optics)
-        sorted = _sort_raytrace(single, max_lost=max_lost_iter)
-        output_list.append(sorted)
-        
-    output = combine_raytrace(output_list)
-
-    if internal is False:
-        if config['general']['print_results']:
-            print_raytrace(output)
-        if config['general']['save_config']:
-            xicsrt_input.save_config(output['config'])
-
-    if config['general']['save_images']:
-        save_images(output)
-
-    profiler.stop('raytrace')
-    #profiler.report()
-    return output
 
 def raytrace(config):
     """
@@ -105,8 +37,8 @@ def raytrace(config):
     is one reason to use this routine rather than just increasing
     the number of iterations: periodic outputs during long computations.
 
-    Also see :func:`~xicsrt.xicsrt_multiprocessing.raytrace_multiprocessing`
-    for a multiprocessing version of this routine.
+    Also see :func:`~xicsrt.xicsrt_multiprocessing.raytrace` for a
+    multiprocessing version of this routine.
     """
     profiler.start('raytrace_multi')
     
@@ -148,33 +80,102 @@ def raytrace(config):
         
     profiler.stop('raytrace_multi')
     return output
-    
+
+def raytrace_single(config, internal=False):
+    """
+    Perform a single raytrace run consisting of multiple iterations.
+
+    If history is enabled, sort the rays into those that are detected and
+    those that are lost (found and lost). The found ray history will be
+    returned in full. The lost ray history will be truncated to allow
+    analysis of lost ray pattern while still limiting memory usage.
+    """
+    profiler.start('raytrace')
+
+    # Update the default config with the user config.
+    config = xicsrt_config.get_config(config)
+    config = xicsrt_config.config_to_numpy(config)
+    check_config(config)
+
+    logging.info('Seeding np.random with {}'.format(config['general']['random_seed']))
+    np.random.seed(config['general']['random_seed'])
+
+    num_iter = config['general']['number_of_iter']
+    max_lost_iter = int(config['general']['history_max_lost']/num_iter)
+
+    # Setup the dispatchers.
+    if 'filters' in config:
+        filters = Dispatcher(config, 'filters')
+        filters.instantiate()
+        filters.setup()
+        filters.initialize()
+        config['filters'] = filters.get_config()
+    else:
+        filters = None
+
+    sources = Dispatcher(config, 'sources')
+    sources.instantiate()
+    sources.apply_filters(filters)
+    sources.setup()
+    sources.initialize()
+    config['sources'] = sources.get_config()
+
+    optics = Dispatcher(config, 'optics')
+    optics.instantiate()
+    optics.setup()
+    optics.initialize()
+    config['optics'] = optics.get_config()
+
+    # Do the actual raytracing
+    output_list = []
+    for ii in range(num_iter):
+        logging.info('Starting iteration: {} of {}'.format(ii + 1, num_iter))
+
+        single = _raytrace_iter(config, sources, optics)
+        sorted = _sort_raytrace(single, max_lost=max_lost_iter)
+        output_list.append(sorted)
+
+    output = combine_raytrace(output_list)
+
+    if internal is False:
+        if config['general']['print_results']:
+            print_raytrace(output)
+        if config['general']['save_config']:
+            xicsrt_input.save_config(output['config'])
+
+    if config['general']['save_images']:
+        save_images(output)
+
+    profiler.stop('raytrace')
+    # profiler.report()
+    return output
+
 def _raytrace_iter(config, sources, optics):
     """ 
-    Perform a single iteration of raytracing with the given
-    sources and optics. The returned rays are unsorted.
+    Perform a single iteration of raytracing with the given sources and optics.
+    The returned rays are unsorted.
     """
     profiler.start('raytrace_single')
 
-    # Copy some config entries to local variables.
-    # This is only to make tho code below more readable.
+    # Setup local names for a few config entries.
+    # This is only to make the code below more readable.
     keep_meta    = config['general']['keep_meta']
     keep_images  = config['general']['keep_images']
     keep_history = config['general']['keep_history']
 
-    rays = sources.generate_rays(history=keep_history)
-    rays = optics.trace(rays, history=keep_history, images=keep_images)
+    rays = sources.generate_rays(keep_history=keep_history)
+    rays = optics.trace(rays, keep_history=keep_history, keep_images=keep_images)
 
     # Combine sources and optics outputs.
     meta    = OrderedDict()
     image   = OrderedDict()
     history = OrderedDict()
     
-    #if keep_meta:
-    for key in sources.meta:
-        meta[key] = sources.meta[key]
-    for key in optics.meta:
-        meta[key] = optics.meta[key]
+    if keep_meta:
+        for key in sources.meta:
+            meta[key] = sources.meta[key]
+        for key in optics.meta:
+            meta[key] = optics.meta[key]
     
     if keep_images:
         for key in sources.image:
@@ -182,7 +183,7 @@ def _raytrace_iter(config, sources, optics):
         for key in optics.image:
             image[key] = optics.image[key]    
     
-    if keep_history:     
+    if keep_history:
         for key in sources.history:
             history[key] = sources.history[key]
         for key in optics.history:
@@ -277,18 +278,18 @@ def combine_raytrace(input_list):
         key_meta_list = list(input_list[0]['total']['meta'][key_opt].keys())
         for key_meta in key_meta_list:
             output['total']['meta'][key_opt][key_meta] = 0
-            for ii_run in range(num_iter):
-                output['total']['meta'][key_opt][key_meta] += input_list[ii_run]['total']['meta'][key_opt][key_meta]
+            for ii_iter in range(num_iter):
+                output['total']['meta'][key_opt][key_meta] += input_list[ii_iter]['total']['meta'][key_opt][key_meta]
 
     # Combine the images.
     for key_opt in key_opt_list:
         if key_opt in input_list[0]['total']['image']:
             output['total']['image'][key_opt] = np.zeros(input_list[0]['total']['image'][key_opt].shape)
-            for ii_run in range(num_iter):
-                output['total']['image'][key_opt] += input_list[ii_run]['total']['image'][key_opt]
+            for ii_iter in range(num_iter):
+                output['total']['image'][key_opt] += input_list[ii_iter]['total']['image'][key_opt]
 
     # Combine all the histories.
-    if len(input_list[ii_run]['found']['history']) > 0:
+    if len(input_list[0]['found']['history']) > 0:
         final_num_found = 0
         final_num_lost = 0
         for ii_run in range(num_iter):
